==> open-cluster-management-agent-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KlusterletAddonConfigSpecBuilder extends KlusterletAddonConfigSpecFluentImpl<KlusterletAddonConfigSpecBuilder> implements VisitableBuilder<KlusterletAddonConfigSpec,KlusterletAddonConfigSpecBuilder>{
  public KlusterletAddonConfigSpecBuilder() {
    this(false);
  }
  public KlusterletAddonConfigSpecBuilder(Boolean validationEnabled) {
    this(new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance) {
    this(fluent, instance, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApplicationManager(instance.getApplicationManager());
      fluent.withCertPolicyController(instance.getCertPolicyController());
      fluent.withClusterLabels(instance.getClusterLabels());
      fluent.withClusterName(instance.getClusterName());
      fluent.withClusterNamespace(instance.getClusterNamespace());
      fluent.withIamPolicyController(instance.getIamPolicyController());
      fluent.withPolicyController(instance.getPolicyController());
      fluent.withProxyConfig(instance.getProxyConfig());
      fluent.withSearchCollector(instance.getSearchCollector());
      fluent.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance) {
    this(instance,false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApplicationManager(instance.getApplicationManager());
      this.withCertPolicyController(instance.getCertPolicyController());
      this.withClusterLabels(instance.getClusterLabels());
      this.withClusterName(instance.getClusterName());
      this.withClusterNamespace(instance.getClusterNamespace());
      this.withIamPolicyController(instance.getIamPolicyController());
      this.withPolicyController(instance.getPolicyController());
      this.withProxyConfig(instance.getProxyConfig());
      this.withSearchCollector(instance.getSearchCollector());
      this.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  KlusterletAddonConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public KlusterletAddonConfigSpec build() {
    KlusterletAddonConfigSpec buildable = new KlusterletAddonConfigSpec(fluent.getApplicationManager(),fluent.getCertPolicyController(),fluent.getClusterLabels(),fluent.getClusterName(),fluent.getClusterNamespace(),fluent.getIamPolicyController(),fluent.getPolicyController(),fluent.getProxyConfig(),fluent.getSearchCollector(),fluent.getVersion());
    return buildable;
  }
  
}

==> open-cluster-management-agent-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KlusterletAddonConfigSpecBuilder extends KlusterletAddonConfigSpecFluent<KlusterletAddonConfigSpecBuilder> implements VisitableBuilder<KlusterletAddonConfigSpec,KlusterletAddonConfigSpecBuilder>{
  public KlusterletAddonConfigSpecBuilder() {
    this(false);
  }
  public KlusterletAddonConfigSpecBuilder(Boolean validationEnabled) {
    this(new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KlusterletAddonConfigSpec(), validationEnabled);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance) {
    this(fluent, instance, false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpecFluent<?> fluent,KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new KlusterletAddonConfigSpec());

    if (instance != null) {
      fluent.withApplicationManager(instance.getApplicationManager());
      fluent.withCertPolicyController(instance.getCertPolicyController());
      fluent.withClusterLabels(instance.getClusterLabels());
      fluent.withClusterName(instance.getClusterName());
      fluent.withClusterNamespace(instance.getClusterNamespace());
      fluent.withIamPolicyController(instance.getIamPolicyController());
      fluent.withPolicyController(instance.getPolicyController());
      fluent.withProxyConfig(instance.getProxyConfig());
      fluent.withSearchCollector(instance.getSearchCollector());
      fluent.withVersion(instance.getVersion());
      fluent.withApplicationManager(instance.getApplicationManager());
      fluent.withCertPolicyController(instance.getCertPolicyController());
      fluent.withClusterLabels(instance.getClusterLabels());
      fluent.withClusterName(instance.getClusterName());
      fluent.withClusterNamespace(instance.getClusterNamespace());
      fluent.withIamPolicyController(instance.getIamPolicyController());
      fluent.withPolicyController(instance.getPolicyController());
      fluent.withProxyConfig(instance.getProxyConfig());
      fluent.withSearchCollector(instance.getSearchCollector());
      fluent.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance) {
    this(instance,false);
  }
  public KlusterletAddonConfigSpecBuilder(KlusterletAddonConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new KlusterletAddonConfigSpec());

    if (instance != null) {
      this.withApplicationManager(instance.getApplicationManager());
      this.withCertPolicyController(instance.getCertPolicyController());
      this.withClusterLabels(instance.getClusterLabels());
      this.withClusterName(instance.getClusterName());
      this.withClusterNamespace(instance.getClusterNamespace());
      this.withIamPolicyController(instance.getIamPolicyController());
      this.withPolicyController(instance.getPolicyController());
      this.withProxyConfig(instance.getProxyConfig());
      this.withSearchCollector(instance.getSearchCollector());
      this.withVersion(instance.getVersion());
      this.withApplicationManager(instance.getApplicationManager());
      this.withCertPolicyController(instance.getCertPolicyController());
      this.withClusterLabels(instance.getClusterLabels());
      this.withClusterName(instance.getClusterName());
      this.withClusterNamespace(instance.getClusterNamespace());
      this.withIamPolicyController(instance.getIamPolicyController());
      this.withPolicyController(instance.getPolicyController());
      this.withProxyConfig(instance.getProxyConfig());
      this.withSearchCollector(instance.getSearchCollector());
      this.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  KlusterletAddonConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public KlusterletAddonConfigSpec build() {
    KlusterletAddonConfigSpec buildable = new KlusterletAddonConfigSpec(fluent.buildApplicationManager(),fluent.buildCertPolicyController(),fluent.getClusterLabels(),fluent.getClusterName(),fluent.getClusterNamespace(),fluent.buildIamPolicyController(),fluent.buildPolicyController(),fluent.buildProxyConfig(),fluent.buildSearchCollector(),fluent.getVersion());
    return buildable;
  }
  
}
